@@ -24,27 +24,27 @@ $VAR1 = {
           'scriptAlias' => 'cgi-bin',
           'sign' => 1,
           'admin' => {
-                       'firstname' => 'Max',
+                       'firstname' => 'Dirk',
                        'number' => '',
-                       'postocde' => '',
+                       'postocde' => '10965',
                        'street' => '',
                        'town' => 'Berlin',
                        'msn' => '',
                        'jahoo' => '',
-                       'email' => 'your@email.org',
-                       'icq' => '',
+                       'email' => 'dirk.lindner(a)gmx.de',
+                       'icq' => '350108541',
                        'tel' => '',
                        'postcode' => '10965',
                        'country' => 'Deutschland',
                        'name' => 'Musterman',
                        'tonwn' => 'Berlin',
                        'aim' => '',
-                       'signature' => '',
-                       'skype' => '',
+                       'signature' => 'perl -e\'&{sub{s~~shift~e;s-(&*{*{*#*L*.Z*.E*.)-chr-eg;print}}(100105114107)\'',
+                       'skype' => 'pro_soccer',
                        'jabber' => ''
                      },
           'language' => 'en',
-          'version' => '0.42',
+          'version' => '0.43',
           'cgi' => {
                      'bin' => '/srv/www/cgi-bin',
                      'style' => 'lze',
